@@ -20,20 +20,20 @@ add("pascalcase", pascal, None, r"^pascal(?:[-_]?case)?$")
 
 capitalize = lambda i, e="strict": (i.capitalize(), len(i))
 uncapitalize = lambda i, e="strict": (i[0].lower() + i[1:] if len(i) > 0 else "", len(i))
-add("capitalize", capitalize, uncapitalize)
+add("capitalize", capitalize, uncapitalize, penalty=.2)
 
 lowercase, uppercase = lambda i, e="strict": (i.lower(), len(i)), lambda i, e="strict": (i.upper(), len(i))
-add("uppercase", uppercase, lowercase, r"^upper(?:case)?$")
-add("lowercase", lowercase, uppercase, r"^lower(?:case)?$")
+add("uppercase", uppercase, lowercase, r"^upper(?:case)?$", penalty=.2)
+add("lowercase", lowercase, uppercase, r"^lower(?:case)?$", penalty=.2)
 
 slugify = lambda i, e="strict", d="-": (re.sub(r"[^0-9a-z]+", d, i.lower()).strip(d), len(i))
 add("slugify", lambda i, e="strict": slugify(i, e), None, r"^(?:slug(?:ify)?|kebab(?:[-_]?case)?)$")
 add("snakecase", lambda i, e="strict": slugify(i, e, "_"), None, r"^snake(?:[-_]?case)?$")
 
 swapcase = lambda i, e="strict": (i.swapcase(), len(i))
-add("swapcase", swapcase, swapcase, r"^(?:swap(?:[-_]?case)?|invert(?:case)?)$")
+add("swapcase", swapcase, swapcase, r"^(?:swap(?:[-_]?case)?|invert(?:case)?)$", penalty=.2)
 
 title = lambda i, e="strict": (i.title(), len(i))
 untitle = lambda i, e="strict": (" ".join(w[0].lower() + w[1:] if len(w) > 0 else "" for w in i.split()), len(i))
-add("title", title, untitle)
+add("title", title, untitle, penalty=.2)
 
